#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWO_HPP_INCLUDED

#include <boost/simd/constant/include/constants/two.hpp>

#endif
